rotationTurns property
The number of clockwise quarter turns the image should be rotated. Defaults to 0.
Implementation
final int rotationTurns;
The number of clockwise quarter turns the image should be rotated. Defaults to 0.
final int rotationTurns;